@@ -1,4 +1,4 @@
-/* $Id: ftp.c,v 1.27 2001/07/09 18:47:54 mhe Exp $
+/* $Id: ftp.c,v 1.31 2002/04/07 18:10:38 mhe Exp $
  *
  * ftp.c -- low(er) level FTP stuff
  *
@@ -266,6 +266,7 @@ static RETSIGTYPE ftp_open_handler(int signum)
 int ftp_open_url(url_t *urlp, bool reset_vars)
 {
 	bool use_proxy;
+	int i;
 
 	if(reset_vars)
 		ftp_reset_vars();
@@ -309,6 +310,10 @@ int ftp_open_url(url_t *urlp, bool reset_vars)
 	}
 	urlp->port = ntohs(ftp->host->port);
 
+	fprintf(stderr, "\r               ");
+	i = strlen(use_proxy ? gvProxyUrl->hostname : urlp->hostname);
+	while(i--)
+		fprintf(stderr, " ");
 	fprintf(stderr, "\r");
 	ftp_trace("\n");
 
@@ -659,7 +664,7 @@ int ftp_cmd(const char *cmd, ...)
 	ftp_set_close_handler();
 	if(resp == 421) { /* server is closing control connection! */
 		ftp_err(_("Server closed control connection\n"));
-		if(gvAutoReconnect && strcasecmp(cmd, "QUIT") != 0) {
+		if(gvAutoReconnect && ftp_loggedin() && strcasecmp(cmd, "QUIT") != 0) {
 			if(recon) {
 				ftp_err(_("Reconnect failed\n"));
 			} else {
@@ -707,7 +712,7 @@ void ftp_set_tmp_verbosity(int verbosity)
 		ftp->tmp_verbosity = verbosity;
 }
 
-static int get_username(url_t *url, const char *guessed_username, bool isproxy)
+int get_username(url_t *url, const char *guessed_username, bool isproxy)
 {
 	if(!url->username) {
 		char *prompt, *e;
@@ -1340,7 +1345,24 @@ rdirectory *ftp_read_directory(const char *path)
 
 	fchmod(fileno(fp), S_IRUSR | S_IWUSR);
 
+	/* we do a "CWD" before the listing, because: we want a listing of
+	 *  the directory contents, not the directory itself, and some
+	 *  servers misunderstand this. If the target is a link to a
+	 *  directory, we have to do this.
+	 */
+	if(!is_curdir) {
+		ftp_cmd("CWD %s", dir);
+		if(ftp->code != ctComplete)
+			goto failed;
+	}
+
 	if(ftp->has_mlsd_command) {
+#if 0
+		/* PureFTPd (1.0.11) doesn't recognize directory arguments
+		 * with spaces, not even quoted, it just chops the argument
+		 * string after the first space, duh... so we have to CWD to
+		 * the directory...
+		 */
 		char *asdf;
 		asprintf(&asdf, "%s/", dir);
 		/* Hack to get around issue in PureFTPd (up to version 0.98.2):
@@ -1349,27 +1371,17 @@ rdirectory *ftp_read_directory(const char *path)
 		 */
 		_failed = (ftp_list("MLSD", asdf, fp) != 0);
 		xfree(asdf);
+#else
+		_failed = (ftp_list("MLSD", 0, fp) != 0);
+#endif
 		if(_failed && ftp->code == ctError)
 			ftp->has_mlsd_command = false;
 	}
-	if(!ftp->has_mlsd_command) {
-
-		/* we do a "CWD" before the listing, because:
-		 *  we want a listing of the directory contents, not the
-		 *  directory itself, and some servers misunderstand this
-		 *  If the target is a link to a directory, we have to do this
-		 */
-		if(!is_curdir) {
-			ftp_cmd("CWD %s", dir);
-			if(ftp->code != ctComplete)
-				goto failed;
-		}
-
+	if(!ftp->has_mlsd_command)
 		_failed = (ftp_list("LIST", 0, fp) != 0);
 
-		if(!is_curdir)
-			ftp_cmd("CWD %s", ftp->curdir);
-	}
+	if(!is_curdir)
+		ftp_cmd("CWD %s", ftp->curdir);
 
 	if(_failed)
 		goto failed;
@@ -1631,10 +1643,10 @@ time_t gmt_mktime(const struct tm *ts)
 	const int SECS_HOUR = SECS_MIN * 60;
 	const int SECS_DAY = SECS_HOUR * 24;
 	const int SECS_YEAR = SECS_DAY * 365;
-	const int daysPerMonth[] = { 31, 28, 31, 30, 31, 30, 31, 30, 31,
-		30, 31, 30 };
-	const int leapDaysPerMonth[] = { 31, 29, 31, 30, 31, 30, 31, 30,
-		31, 30, 31, 30 };
+	const int daysPerMonth[] = { 31, 28, 31, 30, 31, 30, 31, 31, 30,
+		31, 30, 31 };
+	const int leapDaysPerMonth[] = { 31, 29, 31, 30, 31,
+		30, 31, 31, 30, 31, 30, 31 }; 
 	const int *maxDaysInMonth = daysPerMonth;
 
 	time_t gmt = -1;
