@@ -1,4 +1,4 @@
-/* $Id: ftpsend.c,v 1.9 2001/05/12 18:44:04 mhe Exp $
+/* $Id: ftpsend.c,v 1.13 2001/07/16 09:18:13 mhe Exp $
  *
  * ftpsend.c -- send/receive files and file listings
  *
@@ -19,6 +19,7 @@
 #include "ftpsigs.h"
 #include "gvars.h"
 #include "ssh_cmd.h"
+#include "ssh_ftp.h"
 
 static int ftp_pasv(unsigned char result[6])
 {
@@ -316,7 +317,7 @@ static int FILE_recv_binary(FILE *in, FILE *out)
 			ftp_trace("wait_for_input() returned non-zero\n");
 			break;
 		}
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 		n = sec_read(fileno(in), buf, FTP_BUFSIZ);
 #else
 		n = fread(buf, sizeof(char), FTP_BUFSIZ, in);
@@ -376,7 +377,7 @@ static int FILE_send_binary(FILE *in, FILE *out)
 
 		if(wait_for_output() != 0)
 			break;
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 		if(sec_write(fileno(out), buf, n) != n)
 			break;
 #else
@@ -392,7 +393,7 @@ static int FILE_send_binary(FILE *in, FILE *out)
 			}
 		}
 	}
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	sec_fflush(out);
 #endif
 
@@ -403,7 +404,7 @@ static int FILE_send_binary(FILE *in, FILE *out)
 
 static int krb_getc(FILE *fp)
 {
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 	return sec_getc(fp);
 #else
 	return fgetc(fp);
@@ -543,6 +544,7 @@ int ftp_list(const char *cmd, const char *param, FILE *fp)
 	if(ftp_init_transfer() != 0)
 		return -1;
 
+	ftp_set_tmp_verbosity(vbNone);
 	if(param)
 		ftp_cmd("%s %s", cmd, param);
 	else
@@ -927,7 +929,21 @@ int ftp_getfile(const char *infile, const char *outfile, getmode_t how,
 	rp = ftp->restart_offset;
 
 	reset_transfer_info();
-	if(!ftp->ssh_pid && ftp_init_receive(infile, mode, hookf) != 0)
+	if(ftp->ssh_pid) {
+		/* we need to stat the remote file, so we are sure we can read it
+		 * this needs to be done before we call ssh_do_receive, because by
+		 * then, the file is created, and would leave a zero-size file opon
+		 * failure
+		 */
+		Attrib *a = ssh_stat(infile);
+		if(a == 0) {
+			ftp_err(_("Unable to stat file '%s'\n"), infile);
+			return -1;
+		}
+		/* FIXME: how can we check if it will be possible to transfer
+		 * the specified file?
+		 */
+	} else if(ftp_init_receive(infile, mode, hookf) != 0)
 		return -1;
 
 	if(how == getPipe) {
