@@ -1,25 +1,19 @@
-/* host.c -- 
+/* $Id: host.c,v 1.4 2001/05/12 18:44:04 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * host.c -- DNS lookups of hostnames
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
 #include "host.h"
+#include "gvars.h"
 
 /* saved reply from getservent */
 static int ftp_servent_port = -1; /* -1 == not initialized */
@@ -65,7 +59,8 @@ int host_lookup(Host *hostp)
 	/* check if host is given in numbers-and-dots notation */
 	/* FIXME: should check if inet_aton is not present -> use inet_addr() */
 	if(inet_aton(hostp->hostname, &ia)) {
-		hostp->hep = gethostbyaddr((char *)&ia, sizeof(ia), AF_INET);
+		if(gvReverseDNS)
+			hostp->hep = gethostbyaddr((char *)&ia, sizeof(ia), AF_INET);
 		if(hostp->hep == 0) {
 			hostp->alt_h_length = sizeof(ia);
 			memcpy((void *)&hostp->alt_h_addr, &ia, hostp->alt_h_length);
