@@ -1,21 +1,14 @@
-/* gvars.h -- global variables
- * 
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
- * 
+/* $Id: gvars.h,v 1.11 2001/05/13 12:24:25 mhe Exp $
+ *
+ * gvars.h -- global variables
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #ifndef _gvars_h_included
@@ -38,6 +31,20 @@ extern char *gvWorkingDirectory;
 /* try to login automagically */
 extern bool gvAutologin;
 
+/* do reverse DNS lookups? */
+extern bool gvReverseDNS;
+
+/* path to the SSH program */
+extern char *gvSSHProgram ;
+
+/* path to the remote sftp-server program
+ * leave blank to use sftp subsystem
+ */
+extern char *gvSFTPServerProgram;
+
+/* automatically reconnect on connection timeout */
+extern bool gvAutoReconnect;
+
 extern bool gvVerbose;
 extern bool gvDebug;
 extern bool gvTrace;
