@@ -1,21 +1,14 @@
-/* prompt.c -- expands the prompt
+/* $Id: prompt.c,v 1.3 2001/05/12 18:44:37 mhe Exp $
  *
- * This file is part of Yafc, an ftp client.
- * This program is Copyright (C) 1998-2001 martin HedenfaLk
+ * prompt.c -- expands the prompt
+ *
+ * Yet Another FTP Client
+ * Copyright (C) 1998-2001, Martin Hedenfalk <mhe@stacken.kth.se>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * (at your option) any later version. See COPYING for more details.
  */
 
 #include "syshdr.h"
@@ -114,7 +107,8 @@ char *expand_prompt(const char *fmt)
 				} else
 					ins = ftp->url->hostname;
 				break;
-			  case 'm': /* remote machine name (as returned from gethostbynmame) */
+			  case 'm':
+				/* remote machine name (as returned from gethostbynmame) */
 				ins = ftp_connected() ? ftp->host->ohostname : "?";
 				break;
 			  case 'M': /* %m up to first '.' */
@@ -124,7 +118,8 @@ char *expand_prompt(const char *fmt)
 				}
 				e = strchr(ftp->host->ohostname, '.');
 				if(e) {
-					ins = xstrndup(ftp->host->ohostname, e - ftp->host->ohostname);
+					ins = xstrndup(ftp->host->ohostname,
+								   e - ftp->host->ohostname);
 					freeins = true;
 				} else
 					ins = ftp->host->ohostname;
@@ -186,7 +181,8 @@ char *expand_prompt(const char *fmt)
 
 			if(ins) {
 				char *tmp;
-				tmp = (char *)xmalloc(strlen(prompt) + strlen(ins) + strlen(fmt+1) + 1);
+				tmp = (char *)xmalloc(strlen(prompt) + strlen(ins) +
+									  strlen(fmt+1) + 1);
 				strcpy(tmp, prompt);
 				strcat(tmp, ins);
 				cp = tmp + strlen(prompt) + strlen(ins);
